﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

// At design time, set the PictureBox properties:
//      BackColor = Transparent
//      Image = the button up image

namespace howto_picture_button
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        // Keep track of whether the button is pressed.
        private bool ClickMeButtonIsPressed = false;

        // Display the button down image.
        private void picClickMe_MouseDown(object sender, MouseEventArgs e)
        {
            // See if the mouse is over the masked area.
            if (MouseIsOverButton(e.Location))
            {
                ClickMeButtonIsPressed = true;
                picClickMe.Image = Properties.Resources.ButtonDown;
            }
        }

        // Display the button up image.
        private void picClickMe_MouseUp(object sender, MouseEventArgs e)
        {
            ClickMeButtonIsPressed = false;
            picClickMe.Image = Properties.Resources.ButtonUp;
        }

        // If the button is pressed, display the appropriate image.
        private void picClickMe_MouseMove(object sender, MouseEventArgs e)
        {
            // The picture the button should have.
            Image desired_picture = Properties.Resources.ButtonUp;

            // See if the mouse is over the button's masked area.
            if (MouseIsOverButton(e.Location))
            {
                // The mouse is over the masked area.
                // See if the mouse is pressed.
                if (ClickMeButtonIsPressed)
                    desired_picture = Properties.Resources.ButtonDown;
                else
                    desired_picture = Properties.Resources.ButtonMouseOver;
            }
            else
            {
                // The mouse is not over the masked area.
                // The button should be in the up position.
                desired_picture = Properties.Resources.ButtonUp;
            }

            // See if we need to change the button image.
            if (picClickMe.Image != desired_picture)
                picClickMe.Image = desired_picture;
        }

        // Return true if the mouse is over the button's masked area.
        private bool MouseIsOverButton(Point location)
        {
            // Make sure the location is over the image.
            if (location.X < 0) return false;
            if (location.Y < 0) return false;
            if (location.X >= Properties.Resources.ButtonMask.Width) return false;
            if (location.Y >= Properties.Resources.ButtonMask.Height) return false;

            // See if the mask pixel at this position is black.
            Color color =
                Properties.Resources.ButtonMask.GetPixel(
                    location.X, location.Y);
            return ((color.A == 255) &&
                    (color.R == 0) &&
                    (color.G == 0) &&
                    (color.B == 0));
        }

        // The button has been clicked.
        private void picClickMe_MouseClick(object sender, MouseEventArgs e)
        {
            // See if the mouse is over the masked area.
            if (MouseIsOverButton(e.Location))
            {
                MessageBox.Show("Clicked");
            }
        }
    }
}
